module CURIC
  class << self
    attr_accessor :tools_command
  end
  @tools_command ||= UI.menu('Tools').add_submenu('Curic')
  ICON ||= File.join(File.dirname(__FILE__), 'Resources/curic_icon.png')

  module ZoomThrough
    Sketchup.require('curic_zoom_through/observer')

    class << self
      attr_accessor(:observer)
    end

    def self.read_distance
      Sketchup.read_default(PLUGIN_NAME, 'distance', 500.mm.to_f)
    end

    def self.write_distance(distance)
      Sketchup.write_default(PLUGIN_NAME, 'distance', distance.to_f)
    end

    def self.set_distance
      d = read_distance
      r = UI.inputbox(['Distance'], [d.to_l], 'Distance to face')
      return unless r
      
      write_distance(r[0])
    end

    def self.toggle
      @observer.disable = !@observer.disable
    end

    file = __FILE__
    unless file_loaded? file
      # Attach Observer
      @observer = ZoomThroughOb.new

      submenu = CURIC.tools_command.add_submenu(PLUGIN_ID)

      tb = UI::Toolbar.new(PLUGIN_NAME)
      path_to_resources = File.join(File.dirname(__FILE__), 'Resources')

      cmd = UI::Command.new('镜头缩放穿透') { toggle }
      cmd.small_icon = File.join(path_to_resources, 'icon.png')
      cmd.large_icon = File.join(path_to_resources, 'icon.png')
      cmd.tooltip = '镜头缩放穿透'
      cmd.set_validation_proc do
        @observer.disable ? MF_UNCHECKED : MF_CHECKED
      end

      tb.add_item(cmd)
      submenu.add_item(cmd)

      cmd_set_distance = UI::Command.new('设置距离') { set_distance }
      submenu.add_item(cmd_set_distance)

      UI.start_timer(0.1, false) { tb.restore }
      
      file_loaded file
    end
  end
end
